===========================
Tendril Products Primitives
===========================

.. image:: https://img.shields.io/travis/chintal/tendril-products.svg
        :target: https://travis-ci.org/chintal/tendril-products

.. image:: https://img.shields.io/pypi/v/tendril-products.svg
        :target: https://pypi.python.org/pypi/tendril-products

* License: AGPLv3
* Documentation: http://tendril-products.readthedocs.org


Tendril Products Primitives
